@@ -13,15 +13,17 @@
 #include <QRegion>
 #include <QPixmap>
 #include <QBitmap>
-#include <QGuiApplication>
+#include <QApplication>
+#include <QDesktopWidget>
 #include <QScreen>
 
 
 const int UPDATE_TIME = 500;
 
-QtFrameBuffer::QtFrameBuffer(WId id, QObject *parent)
-    : FrameBuffer(id, parent)
+QtFrameBuffer::QtFrameBuffer(QObject *parent)
+    : FrameBuffer(parent)
 {
+    win = QApplication::desktop()->winId();
     QScreen *screen = QGuiApplication::primaryScreen();
     if (screen) {
         primaryScreen = screen;
